@@ -28,6 +28,7 @@
 #include <QString>
 #include <QStringList>
 #include <QUrl>
+#include <QObject>
 #include <cstdio>
 
 int main(int argc, char **argv)
@@ -63,6 +64,9 @@ int main(int argc, char **argv)
             // chunk size in frames
             int chunkSize = args.at(0).toInt();
             args.removeFirst();
+            // chunk size in frames
+            QString profilePath = args.at(0);
+            args.removeFirst();
             // rendered file extension
             QString extension = args.at(0);
             args.removeFirst();
@@ -71,13 +75,13 @@ int main(int argc, char **argv)
             args.removeFirst();
             QDir baseFolder(target);
             Mlt::Factory::init();
-            Mlt::Profile profile;
+            Mlt::Profile profile(profilePath.toUtf8().constData());
+            profile.set_explicit(1);
             Mlt::Producer prod(profile, nullptr, playlist.toUtf8().constData());
             if (!prod.is_valid()) {
                 fprintf(stderr, "INVALID playlist: %s \n", playlist.toUtf8().constData());
+                return 1;
             }
-            profile.from_producer(prod);
-            profile.set_explicit(1);
             const char *localename = prod.get_lcnumeric();
             QLocale::setDefault(QLocale(localename));
             for (const QString &frame : chunks) {
@@ -98,6 +102,7 @@ int main(int argc, char **argv)
                 }
                 if (!cons->is_valid()) {
                     fprintf(stderr, " = =  = INVALID CONSUMER\n\n");
+                    return 1;
                 }
                 cons->set("terminate_on_pause", 1);
                 cons->connect(*playlst);
@@ -113,20 +118,33 @@ int main(int argc, char **argv)
         }
         int in = -1;
         int out = -1;
-        if (LIBMLT_VERSION_INT < 396544) {
-            // older MLT version, does not support consumer in/out, so read it manually
-            QFile f(playlist);
-            QDomDocument doc;
-            doc.setContent(&f, false);
-            f.close();
-            QDomElement consumer = doc.documentElement().firstChildElement(QStringLiteral("consumer"));
-            if (!consumer.isNull()) {
+
+        // older MLT version, does not support embeded consumer in/out in xml, and current 
+        // MLT (6.16) does not pass it onto the multi / movit consumer, so read it manually and enforce
+        QFile f(playlist);
+        QDomDocument doc;
+        doc.setContent(&f, false);
+        f.close();
+        QDomElement consumer = doc.documentElement().firstChildElement(QStringLiteral("consumer"));
+        if (!consumer.isNull()) {
+            if (LIBMLT_VERSION_INT < 397568) {
+                // Previous MLT versions did not correctly pass in and out
                 in = consumer.attribute("in").toInt();
                 out = consumer.attribute("out").toInt();
             }
+            if (consumer.hasAttribute(QLatin1String("s")) || consumer.hasAttribute(QLatin1String("r"))) {
+                // Workaround MLT embeded consumer resize (MLT issue #453)
+                playlist.prepend(QStringLiteral("xml:"));
+                playlist.append(QStringLiteral("?multi=1"));
+            }
         }
-        auto *rJob = new RenderJob(render, playlist, target, pid, in, out);
+
+        auto *rJob = new RenderJob(render, playlist, target, pid, in, out, qApp);
         rJob->start();
+        QObject::connect(rJob, &RenderJob::renderingFinished, [&, rJob]() {
+            rJob->deleteLater();
+            app.quit();
+        }); 
         return app.exec();
     } else {
         fprintf(stderr,
