@@ -451,7 +451,7 @@ Fun KeyframeModel::deleteKeyframe_lambda(GenTime pos, bool notify)
         qDebug() << "delete lambda" << pos.frames(pCore->getCurrentFps()) << notify;
         qDebug() << "before" << getAnimProperty();
         Q_ASSERT(m_keyframeList.count(pos) > 0);
-        Q_ASSERT(pos != GenTime()); // cannot delete initial point
+        //Q_ASSERT(pos != GenTime()); // cannot delete initial point
         int row = static_cast<int>(std::distance(m_keyframeList.begin(), m_keyframeList.find(pos)));
         if (notify) beginRemoveRows(QModelIndex(), row, row);
         m_keyframeList.erase(pos);
@@ -703,7 +703,7 @@ QString KeyframeModel::getAnimProperty() const
     }
     int ix = 0;
     bool first = true;
-    std::shared_ptr<Mlt::Animation> anim;
+    std::shared_ptr<Mlt::Animation> anim(nullptr);
     for (const auto &keyframe : m_keyframeList) {
         if (first) {
             switch (m_paramType) {
@@ -731,9 +731,12 @@ QString KeyframeModel::getAnimProperty() const
         anim->key_set_type(ix, convertToMltType(keyframe.second.first));
         ix++;
     }
-    char *cut = anim->serialize_cut();
-    QString ret(cut);
-    free(cut);
+    QString ret;
+    if (anim) {
+        char *cut = anim->serialize_cut();
+        ret = QString(cut);
+        free(cut);
+    }
     return ret;
 }
 
