@@ -29,6 +29,8 @@
 #include <QHBoxLayout>
 #include <QClipboard>
 #include <QLabel>
+#include <QIcon>
+#include <QToolButton>
 #include <QApplication>
 
 ClickableLabelParamWidget::ClickableLabelParamWidget(std::shared_ptr<AssetParameterModel> model, QModelIndex index, QWidget *parent)
@@ -39,10 +41,20 @@ ClickableLabelParamWidget::ClickableLabelParamWidget(std::shared_ptr<AssetParame
     QString name = m_model->data(m_index, AssetParameterModel::NameRole).toString();
     QString comment = m_model->data(m_index, AssetParameterModel::CommentRole).toString();
     setToolTip(comment);
-    auto *layout = new QVBoxLayout(this);
+    auto *layout = new QHBoxLayout(this);
+    m_tb = new QToolButton(this);
+    m_tb->setCursor(Qt::PointingHandCursor);
+    m_tb->setIcon(QIcon::fromTheme(QStringLiteral("edit-copy")));
     m_label = new QLabel(this);
     m_label->setWordWrap(true);
+    layout->setContentsMargins(0, 0, 0, 0);
+    layout->addWidget(m_tb);
     layout->addWidget(m_label);
+    connect(m_tb, &QToolButton::clicked, [&]() {
+        QClipboard *clipboard = QApplication::clipboard();
+        QString value = m_model->data(m_index, AssetParameterModel::ValueRole).toString();
+        clipboard->setText(value);
+    });
     connect(m_label, &QLabel::linkActivated, [&](const QString &result) {
         QClipboard *clipboard = QApplication::clipboard();
         clipboard->setText(result);
@@ -62,7 +74,9 @@ void ClickableLabelParamWidget::slotRefresh()
 {
     QString value = m_model->data(m_index, AssetParameterModel::ValueRole).toString();
     m_label->setText(QStringLiteral("<a href=\"%1\">").arg(value) + m_displayName + QStringLiteral("</a>"));
-    m_label->setVisible(!value.isEmpty());
+    setVisible(!value.isEmpty());
+    setMinimumHeight(value.isEmpty() ? 0 : m_tb->sizeHint().height());
+    emit updateHeight();
 }
 
 bool ClickableLabelParamWidget::getValue()
