@@ -620,7 +620,7 @@ void Core::invalidateRange(QSize range)
 
 void Core::invalidateItem(ObjectId itemId)
 {
-    if (!m_mainWindow || m_mainWindow->getCurrentTimeline()->loading) return;
+    if (!m_mainWindow || !m_mainWindow->getCurrentTimeline() || m_mainWindow->getCurrentTimeline()->loading) return;
     switch (itemId.first) {
     case ObjectType::TimelineClip:
     case ObjectType::TimelineComposition:
@@ -652,7 +652,7 @@ void Core::updateItemKeyframes(ObjectId id)
 
 void Core::updateItemModel(ObjectId id, const QString &service)
 {
-    if (m_mainWindow && !m_mainWindow->getCurrentTimeline()->loading && service.startsWith(QLatin1String("fade")) && id.first == ObjectType::TimelineClip) {
+    if (m_mainWindow && id.first == ObjectType::TimelineClip && !m_mainWindow->getCurrentTimeline()->loading && service.startsWith(QLatin1String("fade"))) {
         bool startFade = service == QLatin1String("fadein") || service == QLatin1String("fade_from_black");
         m_mainWindow->getCurrentTimeline()->controller()->updateClip(id.second, {startFade ? TimelineModel::FadeInRole : TimelineModel::FadeOutRole});
     }
@@ -744,7 +744,10 @@ MediaCapture *Core::getAudioDevice()
 
 QString Core::getProjectFolderName()
 {
-    return m_monitorManager->getProjectFolder();
+    if (currentDoc()) {
+        return currentDoc()->projectDataFolder() + QDir::separator();
+    }
+    return QString();
 }
 
 QString Core::getTimelineClipBinId(int cid)
