@@ -475,7 +475,7 @@ bool EffectStackModel::appendEffect(const QString &effectId, bool makeCurrent)
         update();
         PUSH_LAMBDA(update, redo);
         PUSH_LAMBDA(update, undo);
-        PUSH_UNDO(undo, redo, i18n("Add effect %1").arg(i18n(effectName.toUtf8().data())));
+        PUSH_UNDO(undo, redo, i18n("Add effect %1", i18n(effectName.toUtf8().data())));
     } else if (makeCurrent) {
         if (auto srvPtr = m_masterService.lock()) {
             srvPtr->set("kdenlive:activeeffect", currentActive);
@@ -591,7 +591,27 @@ bool EffectStackModel::adjustStackLength(bool adjustFromEnd, int oldIn, int oldD
                 PUSH_LAMBDA(refresh, redo);
                 PUSH_LAMBDA(refresh, undo);
             } else {
-                qDebug() << "// NULL Keyframes---------";
+                if (m_ownerId.first == ObjectType::TimelineTrack) {
+                    int oldEffectOut = effect->filter().get_out();
+                    Fun operation = [effect, out, logUndo]() {
+                        effect->setParameter(QStringLiteral("out"), out, logUndo);
+                        return true;
+                    };
+                    bool res = operation();
+                    if (!res) {
+                        return false;
+                    }
+                    if (logUndo) {
+                        Fun reverse = [effect, oldEffectOut]() {
+                            effect->setParameter(QStringLiteral("out"), oldEffectOut, true);
+                            return true;
+                        };
+                        PUSH_LAMBDA(operation, redo);
+                        PUSH_LAMBDA(reverse, undo);
+                    }
+                } else {
+                    qDebug() << "// NULL Keyframes---------";
+                }
             }
         }
     }
