@@ -20,6 +20,7 @@
 #ifndef MAINWINDOW_H
 #define MAINWINDOW_H
 
+#include <QComboBox>
 #include <QDBusAbstractAdaptor>
 #include <QDockWidget>
 #include <QEvent>
@@ -278,6 +279,8 @@ public slots:
     void slotZoomOut(bool zoomOnMouse = false);
     /** @brief Enable or disable the use of timeline zone for edits. */
     void slotSwitchTimelineZone(bool toggled);
+    /** @brief Open the online services search dialog. */
+    void slotDownloadResources();
 
 private slots:
     /** @brief Shows the shortcut dialog. */
@@ -391,6 +394,7 @@ private slots:
     void slotClipInProjectTree();
     // void slotClipToProjectTree();
     void slotSplitAV();
+    void slotSwitchClip();
     void slotSetAudioAlignReference();
     void slotAlignAudio();
     void slotUpdateClipType(QAction *action);
@@ -424,8 +428,6 @@ private slots:
     void slotUpdateProxySettings();
     /** @brief Disable proxies for this project. */
     void slotDisableProxies();
-    /** @brief Open the online services search dialog. */
-    void slotDownloadResources();
 
     /** @brief Process keyframe data sent from a clip to effect / transition stack. */
     void slotProcessImportKeyframes(GraphicsRectItem type, const QString &tag, const QString &keyframes);
@@ -434,7 +436,7 @@ private slots:
 
     void slotThemeChanged(const QString &name);
     /** @brief Close Kdenlive and try to restart it */
-    void slotRestart();
+    void slotRestart(bool clean = false);
     void triggerKey(QKeyEvent *ev);
     /** @brief Update monitor overlay actions on monitor switch */
     void slotUpdateMonitorOverlays(int id, int code);
