@@ -130,7 +130,7 @@ GLWidget::GLWidget(int id, QObject *parent)
     m_blackClip->set("out", 3);
     connect(&m_refreshTimer, &QTimer::timeout, this, &GLWidget::refresh);
     m_producer = m_blackClip;
-
+    rootContext()->setContextProperty("markersModel", 0);
     if (!initGPUAccel()) {
         disableGPUAccel();
     }
@@ -956,6 +956,8 @@ int GLWidget::setProducer(const std::shared_ptr<Mlt::Producer> &producer, bool i
             removeAudioOverlay();
         }
         m_producer = m_blackClip;
+        // Reset markersModel
+        rootContext()->setContextProperty("markersModel", 0);
     }
     // redundant check. postcondition of above is m_producer != null
     if (m_producer) {
@@ -1200,9 +1202,10 @@ int GLWidget::reconfigure(bool reload)
     // use SDL for audio, OpenGL for video
     QString serviceName = property("mlt_service").toString();
     if (reload) {
-        reloadProfile();
         m_blackClip.reset(new Mlt::Producer(pCore->getCurrentProfile()->profile(), "color:black"));
         m_blackClip->set("kdenlive:id", "black");
+        reloadProfile();
+        return error;
     }
     if ((m_consumer == nullptr) || !m_consumer->is_valid() || strcmp(m_consumer->get("mlt_service"), "multi") == 0) {
         if (m_consumer) {
@@ -1212,7 +1215,7 @@ int GLWidget::reconfigure(bool reload)
         }
         QString audioBackend = (KdenliveSettings::external_display()) ? QString("decklink:%1").arg(KdenliveSettings::blackmagic_output_device())
                                                                       : KdenliveSettings::audiobackend();
-        if (serviceName.isEmpty() || serviceName != audioBackend) {
+        if (m_consumer == nullptr || serviceName.isEmpty() || serviceName != audioBackend) {
             m_consumer.reset(new Mlt::FilteredConsumer(pCore->getCurrentProfile()->profile(), audioBackend.toLatin1().constData()));
             if (m_consumer->is_valid()) {
                 serviceName = audioBackend;
@@ -1351,6 +1354,13 @@ float GLWidget::scale() const
 void GLWidget::reloadProfile()
 {
     // The profile display aspect ratio may have changed.
+    if (m_consumer) {
+        // Make sure to delete and rebuild consumer to match profile
+        m_consumer->purge();
+        m_consumer->stop();
+        m_consumer.reset();
+        reconfigure();
+    }
     resizeGL(width(), height());
     refreshSceneLayout();
 }
