@@ -66,6 +66,7 @@ ClipTranscode::ClipTranscode(QStringList urls, const QString &params, QStringLis
         }
         urls_list->setHidden(true);
         connect(source_url, SIGNAL(textChanged(QString)), this, SLOT(slotUpdateParams()));
+        ffmpeg_params->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::MinimumExpanding);
     } else {
         label_source->setHidden(true);
         source_url->setHidden(true);
@@ -76,6 +77,7 @@ ClipTranscode::ClipTranscode(QStringList urls, const QString &params, QStringLis
         for (int i = 0; i < m_urls.count(); ++i) {
             urls_list->addItem(m_urls.at(i));
         }
+        urls_list->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::MinimumExpanding);
     }
     if (!params.isEmpty()) {
         label_profile->setHidden(true);
@@ -112,7 +114,7 @@ ClipTranscode::ClipTranscode(QStringList urls, const QString &params, QStringLis
     connect(&m_transcodeProcess, &QProcess::readyReadStandardOutput, this, &ClipTranscode::slotShowTranscodeInfo);
     connect(&m_transcodeProcess, static_cast<void (QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &ClipTranscode::slotTranscodeFinished);
 
-    ffmpeg_params->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 5);
+    //ffmpeg_params->setMaximumHeight(QFontMetrics(font()).lineSpacing() * 5);
 
     adjustSize();
 }
@@ -157,11 +159,8 @@ void ClipTranscode::slotStartTransCode()
     }
     QString extension = params.section(QStringLiteral("%1"), 1, 1).section(QLatin1Char(' '), 0, 0);
     QString s_url = source_url->url().toLocalFile();
-    if (params.contains(QLatin1String("-i "))) {
-        // Filename must be inserted later
-    } else {
-        parameters << QStringLiteral("-i") << s_url;
-    }
+    bool mltEncoding = s_url.endsWith(QLatin1String(".mlt")) || s_url.endsWith(QLatin1String(".kdenlive"));
+    
     if (QFile::exists(destination + extension)) {
         if (KMessageBox::questionYesNo(this, i18n("File %1 already exists.\nDo you want to overwrite it?", destination + extension)) == KMessageBox::No) {
             // Abort operation
@@ -172,7 +171,48 @@ void ClipTranscode::slotStartTransCode()
             }
             return;
         }
-        parameters << QStringLiteral("-y");
+        if (!mltEncoding) {
+            parameters << QStringLiteral("-y");
+        }
+    }
+    
+    if (mltEncoding) {
+        params.replace(QStringLiteral("%1"), QString("-consumer %1"));
+        const QStringList splitted = params.split(QLatin1Char('-'), QString::SkipEmptyParts);
+        for (const QString &s : splitted) {
+            QString t = s.simplified();
+            if (t.count(QLatin1Char(' ')) == 0) {
+                t.append(QLatin1String("=1"));
+            } else {
+                if (t.contains(QLatin1String("%1"))) {
+                    // file name
+                    parameters.prepend(t.section(QLatin1Char(' '), 1).replace(QLatin1String("%1"), QString("avformat:%1").arg(destination)));
+                    parameters.prepend(QStringLiteral("-consumer"));
+                    continue;
+                }
+                if (t.startsWith(QLatin1String("aspect "))) {
+                    // Fix aspect ratio calculation
+                    t.replace(QLatin1Char(' '), QLatin1String("=@"));
+                    t.replace(QLatin1Char(':'), QLatin1String("/"));
+                } else {
+                    t.replace(QLatin1Char(' '), QLatin1String("="));
+                }
+            }
+            parameters << t;
+        }
+        parameters.prepend(s_url);
+        buttonBox->button(QDialogButtonBox::Abort)->setText(i18n("Abort"));
+        m_destination = destination + extension;
+        m_transcodeProcess.start(KdenliveSettings::rendererpath(), parameters);
+        source_url->setEnabled(false);
+        dest_url->setEnabled(false);
+        button_start->setEnabled(false);
+        return;
+    }
+    if (params.contains(QLatin1String("-i "))) {
+        // Filename must be inserted later
+    } else {
+        parameters << QStringLiteral("-i") << s_url;
     }
 
     bool replaceVfParams = false;
