@@ -61,6 +61,9 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
                                  QLatin1String("black_track")};
     bool ok = true;
     qDebug() << "//////////////////////\nTrying to construct" << tractor.count() << "tracks.\n////////////////////////////////";
+    QList <int> videoTracksIndexes;
+    // Black track index
+    videoTracksIndexes << 0;
     for (int i = 0; i < tractor.count() && ok; i++) {
         std::unique_ptr<Mlt::Producer> track(tractor.track(i));
         QString playlist_name = track->get("id");
@@ -76,6 +79,9 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
             // that is a double track
             int tid;
             bool audioTrack = track->get_int("kdenlive:audio_track") == 1;
+            if (!audioTrack) {
+                videoTracksIndexes << i;
+            }
             ok = timeline->requestTrackInsertion(-1, tid, QString(), audioTrack, undo, redo, false);
             int lockState = track->get_int("kdenlive:locked_track");
             Mlt::Tractor local_tractor(*track);
@@ -94,6 +100,9 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
             Mlt::Playlist local_playlist(*track);
             const QString trackName = local_playlist.get("kdenlive:track_name");
             bool audioTrack = local_playlist.get_int("kdenlive:audio_track") == 1;
+            if (!audioTrack) {
+                videoTracksIndexes << i;
+            }
             ok = timeline->requestTrackInsertion(-1, tid, trackName, audioTrack, undo, redo, false);
             int muteState = track->get_int("hide");
             if (muteState > 0 && (!audioTrack || (audioTrack && muteState != 1))) {
@@ -136,7 +145,6 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
     bool compositionOk = true;
     while (!compositions.isEmpty()) {
         QScopedPointer<Mlt::Transition> t(compositions.takeFirst());
-        auto transProps = std::make_unique<Mlt::Properties>(t->get_properties());
         QString id(t->get("kdenlive_id"));
         int compoId;
         int aTrack = t->get_a_track();
@@ -145,9 +153,17 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
                                        t->get_in(), t->get_a_track());
             continue;
         }
-
-        compositionOk = timeline->requestCompositionInsertion(id, timeline->getTrackIndexFromPosition(t->get_b_track() - 1), t->get_a_track(), t->get_in(),
-                                                                  t->get_length(), std::move(transProps), compoId, undo, redo);
+        if (t->get_int("force_track") == 0) {
+            // This is an automatic composition, check that we composite with lower track or warn
+            int pos = videoTracksIndexes.indexOf(t->get_b_track());
+            if (pos > 0 && videoTracksIndexes.at(pos - 1) != aTrack) {
+                t->set("force_track", 1);
+                m_errorMessage << i18n("Incorrect composition %1 found on track %2 at %3, compositing with track %4 was set to forced track.", t->get("id"), t->get_b_track(),
+                                    t->get_in(), t->get_a_track());
+            }
+        }
+        auto transProps = std::make_unique<Mlt::Properties>(t->get_properties());
+        compositionOk = timeline->requestCompositionInsertion(id, timeline->getTrackIndexFromPosition(t->get_b_track() - 1), t->get_a_track(), t->get_in(), t->get_length(), std::move(transProps), compoId, undo, redo);
         if (!compositionOk) {
             qDebug() << "ERROR : failed to insert composition in track " << t->get_b_track() << ", position" << t->get_in() << ", ID: " << id
                          << ", MLT ID: " << t->get("id");
@@ -278,13 +294,15 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
                     clipId = clip->get("kdenlive:id");
                 }
                 if (binIdCorresp.count(clipId) == 0) {
-                    QStringList ids = pCore->projectItemModel()->getClipByUrl(QFileInfo(clip->parent().get("resource")));
-                    if (!ids.isEmpty()) {
-                        binId = ids.first();
-                        m_errorMessage << i18n("Invalid clip %1 found on track %2 at %3.", clip->parent().get("id"), track.get("id"), position);
+                    // Project was somehow corrupted
+                    qDebug()<<"=== WARNING, CANNOT FIND CLIP WITH ID: "<<clipId<<" IN BIN PLAYLIST";
+                    QStringList fixedId = pCore->projectItemModel()->getClipByUrl(QFileInfo(clip->parent().get("resource")));
+                    if (!fixedId.isEmpty()) {
+                        binId = fixedId.first();
+                        m_errorMessage << i18n("Invalid clip %1 (%2) not found in project bin, recovered.", clip->parent().get("id"), clipId);
                     } else {
                         qWarning()<<"Warning, clip in timeline has no parent in bin: "<<clip->parent().get("id");
-                        m_errorMessage << i18n("Invalid clip %1 found on track %2 at %3.", clip->parent().get("id"), track.get("id"), position);
+                        m_errorMessage << i18n("Project corrupted. Clip %1 (%2) not found in project bin.", clip->parent().get("id"), clipId);
                     }
                 } else {
                     binId = binIdCorresp.at(clipId);
@@ -298,7 +316,7 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
             if (pCore->bin()->getBinClip(binId)) {
                 PlaylistState::ClipState st = inferState(clip, audioTrack);
                 cid = ClipModel::construct(timeline, binId, clip, st);
-                ok = timeline->requestClipMove(cid, tid, position, true, false, true, undo, redo);
+                ok = timeline->requestClipMove(cid, tid, position, true, true, false, true, undo, redo);
             } else {
                 qDebug() << "// Cannot find bin clip: " << binId << " - " << clip->get("id");
             }
