@@ -171,6 +171,7 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
     int outPoint = out;
     int inPoint = in;
     int offset = 0;
+    int trackDuration = 0;
     if (m_endlessResize) {
         offset = inPoint;
         outPoint = out - in;
@@ -181,6 +182,9 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
             if (ptr->getTrackById(m_currentTrackId)->isLocked()) {
                 return false;
             }
+            if (right && ptr->getTrackById_const(m_currentTrackId)->isLastClip(getPosition())) {
+                trackDuration = ptr->getTrackById_const(m_currentTrackId)->trackDuration();
+            }
             track_operation = ptr->getTrackById(m_currentTrackId)->requestClipResize_lambda(m_id, inPoint, outPoint, right);
         } else {
             qDebug() << "Error : Moving clip failed because parent timeline is not available anymore";
@@ -219,6 +223,14 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
             // Now, we are in the state in which the timeline should be when we try to revert current action. So we can build the reverse action from here
             if (m_currentTrackId != -1) {
                 if (auto ptr = m_parent.lock()) {
+                    if (trackDuration > 0) {
+                        // Operation changed parent track duration, update effect stack
+                        int newDuration = ptr->getTrackById_const(m_currentTrackId)->trackDuration();
+                        if (logUndo || trackDuration != newDuration) {
+                            // A clip move changed the track duration, update track effects
+                            ptr->getTrackById(m_currentTrackId)->m_effectStack->adjustStackLength(true, 0, trackDuration, 0, newDuration, 0, undo, redo, logUndo);
+                        }
+                    }
                     track_reverse = ptr->getTrackById(m_currentTrackId)->requestClipResize_lambda(m_id, old_in, old_out, right);
                 }
             }
@@ -431,7 +443,7 @@ bool ClipModel::useTimewarpProducer(double speed, bool changeDuration, Fun &undo
     std::function<bool(void)> local_redo = []() { return true; };
     double previousSpeed = getSpeed();
     int oldDuration = getPlaytime();
-    int newDuration = int(double(oldDuration) * std::abs(previousSpeed / speed) + 0.5);
+    int newDuration = qRound(oldDuration * std::fabs(m_speed / speed));
     int oldOut = getOut();
     int oldIn = getIn();
     bool revertSpeed = false;
@@ -457,13 +469,13 @@ bool ClipModel::useTimewarpProducer(double speed, bool changeDuration, Fun &undo
     if (revertSpeed) {
         int in = getIn();
         int out = getOut();
-        int duration = out - in;
-        in = qMax(0, (int)(m_producer->get_length() * std::fabs(m_speed) - out - 1));
-        out = in + duration;
+        in = qMax(0, qRound((m_producer->get_length() - 1 - out)* std::fabs(m_speed/speed) + 0.5));
+        out = in + newDuration;
         operation = [operation, in, out, this]() {
             bool res = operation();
             if (res) {
                 setInOut(in, out);
+            } else {
             }
             return res;
         };
@@ -473,10 +485,14 @@ bool ClipModel::useTimewarpProducer(double speed, bool changeDuration, Fun &undo
         UPDATE_UNDO_REDO(operation, reverse, local_undo, local_redo);
         // When calculating duration, result can be a few frames longer than possible duration so adjust
         if (changeDuration) {
-            bool res = requestResize(qMin(newDuration, getMaxDuration()), true, local_undo, local_redo, true);
-            if (!res) {
-                local_undo();
-                return false;
+            int requestedDuration = qMin(newDuration, getMaxDuration() - getIn());
+            if (requestedDuration != getPlaytime()) {
+                bool res = requestResize(requestedDuration, true, local_undo, local_redo, true);
+                if (!res) {
+                    qDebug()<<"==== CLIP WARP UPDATE DURATION FAILED!!!!";
+                    local_undo();
+                    return false;
+                }
             }
         }
         adjustEffectLength(false, oldIn, getIn(), oldOut - oldIn, m_producer->get_playtime(), 0, local_undo, local_redo, true);
