@@ -180,7 +180,6 @@ bool TimelineFunctions::requestClipCut(const std::shared_ptr<TimelineItemModel>
 
     int count = 0;
     QList<int> newIds;
-    int mainId = -1;
     QList<int> clipsToCut;
     for (int cid : clips) {
         if (!timeline->isClip(cid)) {
@@ -204,9 +203,6 @@ bool TimelineFunctions::requestClipCut(const std::shared_ptr<TimelineItemModel>
             Q_ASSERT(undone);
             return false;
         }
-        if (cid == clipId) {
-            mainId = newId;
-        }
         // splitted elements go temporarily in the same group as original ones.
         timeline->m_groups->setInGroupOf(newId, cid, undo, redo);
         newIds << newId;
@@ -613,14 +609,12 @@ bool TimelineFunctions::changeClipState(const std::shared_ptr<TimelineItemModel>
 {
     int track = timeline->getClipTrackId(clipId);
     int start = -1;
-    int end = -1;
     bool invalidate = false;
     if (track > -1) {
         if (!timeline->getTrackById_const(track)->isAudioTrack()) {
             invalidate = true;
         }
         start = timeline->getItemPosition(clipId);
-        end = start + timeline->getItemPlaytime(clipId);
     }
     Fun local_undo = []() { return true; };
     Fun local_redo = []() { return true; };
@@ -785,7 +779,7 @@ void TimelineFunctions::setCompositionATrack(const std::shared_ptr<TimelineItemM
     pCore->pushUndo(undo, redo, i18n("Change Composition Track"));
 }
 
-void TimelineFunctions::enableMultitrackView(const std::shared_ptr<TimelineItemModel> &timeline, bool enable)
+void TimelineFunctions::enableMultitrackView(const std::shared_ptr<TimelineItemModel> &timeline, bool enable, bool refresh)
 {
     QList<int> videoTracks;
     for (const auto &track : timeline->m_iteratorTable) {
@@ -936,7 +930,9 @@ void TimelineFunctions::enableMultitrackView(const std::shared_ptr<TimelineItemM
         }
     }
     field->unlock();
-    timeline->requestMonitorRefresh();
+    if (refresh) {
+        timeline->requestMonitorRefresh();
+    }
 }
 
 void TimelineFunctions::saveTimelineSelection(const std::shared_ptr<TimelineItemModel> &timeline, const std::unordered_set<int> &selection,
@@ -1283,7 +1279,6 @@ bool TimelineFunctions::pasteClips(const std::shared_ptr<TimelineItemModel> &tim
     //qDebug()<<"== GOT WANTED TKS\n VIDEO: "<<videoTracks<<"\n AUDIO TKS: "<<audioTracks<<"\n SINGLE AUDIO: "<<singleAudioTracks;
     int requestedVideoTracks = videoTracks.isEmpty() ? 0 : videoTracks.last() - videoTracks.first() + 1;
     int requestedAudioTracks = audioTracks.isEmpty() ? 0 : audioTracks.last() - audioTracks.first() + 1;
-    int requestedSingleAudioTracks = singleAudioTracks.isEmpty() ? 0 : singleAudioTracks.last() - singleAudioTracks.first() + 1;
     if (requestedVideoTracks > projectTracks.second.size() || requestedAudioTracks > projectTracks.first.size()) {
         pCore->displayMessage(i18n("Not enough tracks to paste clipboard"), InformationMessage, 500);
         return false;
